Module: Google::Apis::ParallelstoreV1
- Defined in:
- lib/google/apis/parallelstore_v1.rb,
lib/google/apis/parallelstore_v1/classes.rb,
lib/google/apis/parallelstore_v1/service.rb,
lib/google/apis/parallelstore_v1/gem_version.rb,
lib/google/apis/parallelstore_v1/representations.rb
Overview
Parallelstore API
Defined Under Namespace
Classes: CancelOperationRequest, DestinationGcsBucket, DestinationParallelstore, ExportDataRequest, GoogleProtobufEmpty, ImportDataRequest, Instance, ListInstancesResponse, ListLocationsResponse, ListOperationsResponse, Location, Operation, OperationMetadata, ParallelstoreService, ReconciliationOperationMetadata, SourceGcsBucket, SourceParallelstore, Status, TransferMetadataOptions
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-parallelstore_v1 gem
"0.13.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20251022"- VERSION =
Version of the Parallelstore API this client connects to. This is NOT the gem version.
'V1'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'