Class: Google::Apis::ParallelstoreV1::DestinationGcsBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parallelstore_v1/classes.rb,
lib/google/apis/parallelstore_v1/representations.rb,
lib/google/apis/parallelstore_v1/representations.rb

Overview

Cloud Storage as the destination of a data transfer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DestinationGcsBucket

Returns a new instance of DestinationGcsBucket.



48
49
50
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 48

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#uriString

Required. URI to a Cloud Storage bucket in the format: gs:///. The path inside the bucket is optional. Corresponds to the JSON property uri

Returns:

  • (String)


46
47
48
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 46

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53
54
55
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 53

def update!(**args)
  @uri = args[:uri] if args.key?(:uri)
end