Class: Google::Apis::ParallelstoreV1::ExportDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parallelstore_v1/classes.rb,
lib/google/apis/parallelstore_v1/representations.rb,
lib/google/apis/parallelstore_v1/representations.rb

Overview

Export data from Parallelstore to Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportDataRequest

Returns a new instance of ExportDataRequest.



121
122
123
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_gcs_bucketGoogle::Apis::ParallelstoreV1::DestinationGcsBucket

Cloud Storage as the destination of a data transfer. Corresponds to the JSON property destinationGcsBucket



85
86
87
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 85

def destination_gcs_bucket
  @destination_gcs_bucket
end

#metadata_optionsGoogle::Apis::ParallelstoreV1::TransferMetadataOptions

Transfer metadata options for the instance. Corresponds to the JSON property metadataOptions



90
91
92
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 90

def 
  @metadata_options
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


104
105
106
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 104

def request_id
  @request_id
end

#service_accountString

Optional. User-specified Service Account (SA) credentials to be used when performing the transfer. Use one of the following formats: * EMAIL_ADDRESS_OR_UNIQUE_ID * projects/PROJECT_ID_OR_NUMBER/ serviceAccounts/EMAIL_ADDRESS_OR_UNIQUE_ID* `projects/-/serviceAccounts/` EMAIL_ADDRESS_OR_UNIQUE_ID If unspecified, the Parallelstore service agent is used: service-@gcp-sa-parallelstore.iam.gserviceaccount.com Corresponds to the JSON property serviceAccount

Returns:

  • (String)


114
115
116
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 114

def 
  @service_account
end

#source_parallelstoreGoogle::Apis::ParallelstoreV1::SourceParallelstore

Parallelstore as the source of a data transfer. Corresponds to the JSON property sourceParallelstore



119
120
121
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 119

def source_parallelstore
  @source_parallelstore
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



126
127
128
129
130
131
132
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 126

def update!(**args)
  @destination_gcs_bucket = args[:destination_gcs_bucket] if args.key?(:destination_gcs_bucket)
  @metadata_options = args[:metadata_options] if args.key?(:metadata_options)
  @request_id = args[:request_id] if args.key?(:request_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_parallelstore = args[:source_parallelstore] if args.key?(:source_parallelstore)
end