Class: Google::Apis::ParallelstoreV1::ImportDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parallelstore_v1/classes.rb,
lib/google/apis/parallelstore_v1/representations.rb,
lib/google/apis/parallelstore_v1/representations.rb

Overview

Import data from Cloud Storage into a Parallelstore instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportDataRequest

Returns a new instance of ImportDataRequest.



194
195
196
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_parallelstoreGoogle::Apis::ParallelstoreV1::DestinationParallelstore

Parallelstore as the destination of a data transfer. Corresponds to the JSON property destinationParallelstore



158
159
160
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 158

def destination_parallelstore
  @destination_parallelstore
end

#metadata_optionsGoogle::Apis::ParallelstoreV1::TransferMetadataOptions

Transfer metadata options for the instance. Corresponds to the JSON property metadataOptions



163
164
165
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 163

def 
  @metadata_options
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


177
178
179
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 177

def request_id
  @request_id
end

#service_accountString

Optional. User-specified service account credentials to be used when performing the transfer. Use one of the following formats: * EMAIL_ADDRESS_OR_UNIQUE_ID * projects/PROJECT_ID_OR_NUMBER/ serviceAccounts/EMAIL_ADDRESS_OR_UNIQUE_ID* `projects/-/serviceAccounts/` EMAIL_ADDRESS_OR_UNIQUE_ID If unspecified, the Parallelstore service agent is used: service-@gcp-sa-parallelstore.iam.gserviceaccount.com Corresponds to the JSON property serviceAccount

Returns:

  • (String)


187
188
189
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 187

def 
  @service_account
end

#source_gcs_bucketGoogle::Apis::ParallelstoreV1::SourceGcsBucket

Cloud Storage as the source of a data transfer. Corresponds to the JSON property sourceGcsBucket



192
193
194
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 192

def source_gcs_bucket
  @source_gcs_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



199
200
201
202
203
204
205
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 199

def update!(**args)
  @destination_parallelstore = args[:destination_parallelstore] if args.key?(:destination_parallelstore)
  @metadata_options = args[:metadata_options] if args.key?(:metadata_options)
  @request_id = args[:request_id] if args.key?(:request_id)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_gcs_bucket = args[:source_gcs_bucket] if args.key?(:source_gcs_bucket)
end