Class: Google::Apis::ParallelstoreV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/parallelstore_v1/classes.rb,
lib/google/apis/parallelstore_v1/representations.rb,
lib/google/apis/parallelstore_v1/representations.rb

Overview

A Parallelstore instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



310
311
312
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_pointsArray<String>

Output only. A list of IPv4 addresses used for client side configuration. Corresponds to the JSON property accessPoints

Returns:

  • (Array<String>)


215
216
217
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 215

def access_points
  @access_points
end

#capacity_gibFixnum

Required. Immutable. The instance's storage capacity in Gibibytes (GiB). Allowed values are between 12000 and 100000, in multiples of 4000; e.g., 12000, 16000, 20000, ... Corresponds to the JSON property capacityGib

Returns:

  • (Fixnum)


222
223
224
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 222

def capacity_gib
  @capacity_gib
end

#create_timeString

Output only. The time when the instance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


227
228
229
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 227

def create_time
  @create_time
end

#daos_versionString

Output only. Deprecated: The version of DAOS software running in the instance. Corresponds to the JSON property daosVersion

Returns:

  • (String)


232
233
234
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 232

def daos_version
  @daos_version
end

#deployment_typeString

Optional. Immutable. The deployment type of the instance. Allowed values are: * SCRATCH: the instance is a scratch instance. * PERSISTENT: the instance is a persistent instance. Corresponds to the JSON property deploymentType

Returns:

  • (String)


239
240
241
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 239

def deployment_type
  @deployment_type
end

#descriptionString

Optional. The description of the instance. 2048 characters or less. Corresponds to the JSON property description

Returns:

  • (String)


244
245
246
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 244

def description
  @description
end

#directory_stripe_levelString

Optional. Immutable. Stripe level for directories. Allowed values are: * DIRECTORY_STRIPE_LEVEL_MIN: recommended when directories contain a small number of files. * DIRECTORY_STRIPE_LEVEL_BALANCED: balances performance for workloads involving a mix of small and large directories. * DIRECTORY_STRIPE_LEVEL_MAX: recommended for directories with a large number of files. Corresponds to the JSON property directoryStripeLevel

Returns:

  • (String)


254
255
256
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 254

def directory_stripe_level
  @directory_stripe_level
end

#effective_reserved_ip_rangeString

Output only. Immutable. The ID of the IP address range being used by the instance's VPC network. This field is populated by the service and contains the value currently used by the service. Corresponds to the JSON property effectiveReservedIpRange

Returns:

  • (String)


261
262
263
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 261

def effective_reserved_ip_range
  @effective_reserved_ip_range
end

#file_stripe_levelString

Optional. Immutable. Stripe level for files. Allowed values are: * FILE_STRIPE_LEVEL_MIN: offers the best performance for small size files. * FILE_STRIPE_LEVEL_BALANCED: balances performance for workloads involving a mix of small and large files. * FILE_STRIPE_LEVEL_MAX: higher throughput performance for larger files. Corresponds to the JSON property fileStripeLevel

Returns:

  • (String)


270
271
272
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 270

def file_stripe_level
  @file_stripe_level
end

#labelsHash<String,String>

Optional. Cloud Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies. See https://cloud.google.com/resource-manager/docs/ labels-overview for details. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


278
279
280
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 278

def labels
  @labels
end

#nameString

Identifier. The resource name of the instance, in the format projects/ project/locations/location/instances/instance_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


284
285
286
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 284

def name
  @name
end

#networkString

Optional. Immutable. The name of the Compute Engine VPC network to which the instance is connected. Corresponds to the JSON property network

Returns:

  • (String)


290
291
292
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 290

def network
  @network
end

#reserved_ip_rangeString

Optional. Immutable. The ID of the IP address range being used by the instance' s VPC network. See Configure a VPC network. If no ID is provided, all ranges are considered. Corresponds to the JSON property reservedIpRange

Returns:

  • (String)


298
299
300
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 298

def reserved_ip_range
  @reserved_ip_range
end

#stateString

Output only. The instance state. Corresponds to the JSON property state

Returns:

  • (String)


303
304
305
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 303

def state
  @state
end

#update_timeString

Output only. The time when the instance was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 308

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 315

def update!(**args)
  @access_points = args[:access_points] if args.key?(:access_points)
  @capacity_gib = args[:capacity_gib] if args.key?(:capacity_gib)
  @create_time = args[:create_time] if args.key?(:create_time)
  @daos_version = args[:daos_version] if args.key?(:daos_version)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @directory_stripe_level = args[:directory_stripe_level] if args.key?(:directory_stripe_level)
  @effective_reserved_ip_range = args[:effective_reserved_ip_range] if args.key?(:effective_reserved_ip_range)
  @file_stripe_level = args[:file_stripe_level] if args.key?(:file_stripe_level)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @reserved_ip_range = args[:reserved_ip_range] if args.key?(:reserved_ip_range)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end