Class: Google::Apis::ParallelstoreV1::ParallelstoreService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ParallelstoreV1::ParallelstoreService
- Defined in:
- lib/google/apis/parallelstore_v1/service.rb
Overview
Parallelstore API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://parallelstore.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Creates a Parallelstore instance in a given project and location.
-
#delete_project_location_instance(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Deletes a single instance.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#export_instance_data(name, export_data_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Copies data from Parallelstore to Cloud Storage.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Location
Gets information about a location.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Instance
Gets details of a single instance.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Gets the latest state of a long-running operation.
-
#import_instance_data(name, import_data_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Copies data from Cloud Storage to Parallelstore.
-
#initialize ⇒ ParallelstoreService
constructor
A new instance of ParallelstoreService.
-
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::ListInstancesResponse
Lists all instances in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_instance(name, instance_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Updates the parameters of a single instance.
Constructor Details
#initialize ⇒ ParallelstoreService
Returns a new instance of ParallelstoreService.
47 48 49 50 51 52 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-parallelstore_v1', client_version: Google::Apis::ParallelstoreV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 448 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ParallelstoreV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ParallelstoreV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ParallelstoreV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Creates a Parallelstore instance in a given project and location.
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 170 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/instances', ) command.request_representation = Google::Apis::ParallelstoreV1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::ParallelstoreV1::Operation::Representation command.response_class = Google::Apis::ParallelstoreV1::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Deletes a single instance.
215 216 217 218 219 220 221 222 223 224 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 215 def delete_project_location_instance(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ParallelstoreV1::Operation::Representation command.response_class = Google::Apis::ParallelstoreV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
483 484 485 486 487 488 489 490 491 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 483 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ParallelstoreV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::ParallelstoreV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#export_instance_data(name, export_data_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Copies data from Parallelstore to Cloud Storage.
247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 247 def export_instance_data(name, export_data_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:exportData', ) command.request_representation = Google::Apis::ParallelstoreV1::ExportDataRequest::Representation command.request_object = export_data_request_object command.response_representation = Google::Apis::ParallelstoreV1::Operation::Representation command.response_class = Google::Apis::ParallelstoreV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParallelstoreV1::Location::Representation command.response_class = Google::Apis::ParallelstoreV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Instance
Gets details of a single instance.
280 281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 280 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParallelstoreV1::Instance::Representation command.response_class = Google::Apis::ParallelstoreV1::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
514 515 516 517 518 519 520 521 522 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 514 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ParallelstoreV1::Operation::Representation command.response_class = Google::Apis::ParallelstoreV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_instance_data(name, import_data_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Copies data from Cloud Storage to Parallelstore.
311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 311 def import_instance_data(name, import_data_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:importData', ) command.request_representation = Google::Apis::ParallelstoreV1::ImportDataRequest::Representation command.request_object = import_data_request_object command.response_representation = Google::Apis::ParallelstoreV1::Operation::Representation command.response_class = Google::Apis::ParallelstoreV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::ListInstancesResponse
Lists all instances in a given project and location.
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 354 def list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/instances', ) command.response_representation = Google::Apis::ParallelstoreV1::ListInstancesResponse::Representation command.response_class = Google::Apis::ParallelstoreV1::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
558 559 560 561 562 563 564 565 566 567 568 569 570 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 558 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::ParallelstoreV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ParallelstoreV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::ListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ParallelstoreV1::ListLocationsResponse::Representation command.response_class = Google::Apis::ParallelstoreV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ParallelstoreV1::Operation
Updates the parameters of a single instance.
406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/google/apis/parallelstore_v1/service.rb', line 406 def patch_project_location_instance(name, instance_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ParallelstoreV1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::ParallelstoreV1::Operation::Representation command.response_class = Google::Apis::ParallelstoreV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |