Class: Google::Apis::ParallelstoreV1::SourceGcsBucket
- Inherits:
-
Object
- Object
- Google::Apis::ParallelstoreV1::SourceGcsBucket
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/parallelstore_v1/classes.rb,
lib/google/apis/parallelstore_v1/representations.rb,
lib/google/apis/parallelstore_v1/representations.rb
Overview
Cloud Storage as the source of a data transfer.
Instance Attribute Summary collapse
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceGcsBucket
constructor
A new instance of SourceGcsBucket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceGcsBucket
Returns a new instance of SourceGcsBucket.
627 628 629 |
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#uri ⇒ String
Required. URI to a Cloud Storage bucket in the format: gs:///. The path
inside the bucket is optional.
Corresponds to the JSON property uri
625 626 627 |
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 625 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
632 633 634 |
# File 'lib/google/apis/parallelstore_v1/classes.rb', line 632 def update!(**args) @uri = args[:uri] if args.key?(:uri) end |